==> jc-1.4.0.tar.gz: soot/javaToJimple/jj/Topics.h <==
// public class soot.javaToJimple.jj.Topics

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ddb1ed813c91a10 soot_javaToJimple_jj_Topics

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_javaToJimple_jj_Topics_H_
#define _JC_soot_javaToJimple_jj_Topics_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_jj_Topics$sub_refs	_jc_soot_javaToJimple_jj_Topics$sub_refs;
typedef struct _jc_soot_javaToJimple_jj_Topics$sub_nonrefs	_jc_soot_javaToJimple_jj_Topics$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_jj_Topics$refs	_jc_soot_javaToJimple_jj_Topics$refs;
typedef struct _jc_soot_javaToJimple_jj_Topics$nonrefs	_jc_soot_javaToJimple_jj_Topics$nonrefs;
typedef struct _jc_soot_javaToJimple_jj_Topics$object	_jc_soot_javaToJimple_jj_Topics$object;

typedef struct _jc_soot_javaToJimple_jj_Topics$fields_struct	_jc_soot_javaToJimple_jj_Topics$fields_struct;
typedef const struct _jc_soot_javaToJimple_jj_Topics$vmethods	_jc_soot_javaToJimple_jj_Topics$vmethods;
typedef const struct _jc_soot_javaToJimple_jj_Topics$vtable	_jc_soot_javaToJimple_jj_Topics$vtable;
typedef const struct _jc_soot_javaToJimple_jj_Topics$vtype	_jc_soot_javaToJimple_jj_Topics$vtype;

// Class fields structure
struct _jc_soot_javaToJimple_jj_Topics$fields_struct {
	struct _jc_java_lang_String$object	*jj;
};
extern _jc_soot_javaToJimple_jj_Topics$fields_struct _jc_soot_javaToJimple_jj_Topics$class_fields;

// Constructors
extern void _jc_soot_javaToJimple_jj_Topics$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_jj_Topics$object *);

// Static methods
extern void _jc_soot_javaToJimple_jj_Topics$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_soot_javaToJimple_jj_Topics$vmethods {
};

// Vtable
struct _jc_soot_javaToJimple_jj_Topics$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_javaToJimple_jj_Topics$vmethods	soot_javaToJimple_jj_Topics;
};

// Vtype
struct _jc_soot_javaToJimple_jj_Topics$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_jj_Topics$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_jj_Topics$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_jj_Topics$refs {
    _jc_soot_javaToJimple_jj_Topics$sub_refs	soot_javaToJimple_jj_Topics;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_jj_Topics$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_jj_Topics$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_javaToJimple_jj_Topics$sub_nonrefs	soot_javaToJimple_jj_Topics;
};

// Object instance structure
struct _jc_soot_javaToJimple_jj_Topics$object {
	_jc_soot_javaToJimple_jj_Topics$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_jj_Topics$vtype	*vtype;
	_jc_soot_javaToJimple_jj_Topics$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_jj_Topics$vtype _jc_soot_javaToJimple_jj_Topics$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_jj_Topics, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_jj_Topics$class_object;

#endif	/* _JC_soot_javaToJimple_jj_Topics_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/jj/Topics.h <==
// public class soot.javaToJimple.jj.Topics

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ddb1ed813c91a10 soot_javaToJimple_jj_Topics

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_javaToJimple_jj_Topics_H_
#define _JC_soot_javaToJimple_jj_Topics_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_jj_Topics$sub_refs	_jc_soot_javaToJimple_jj_Topics$sub_refs;
typedef struct _jc_soot_javaToJimple_jj_Topics$sub_nonrefs	_jc_soot_javaToJimple_jj_Topics$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_jj_Topics$refs	_jc_soot_javaToJimple_jj_Topics$refs;
typedef struct _jc_soot_javaToJimple_jj_Topics$nonrefs	_jc_soot_javaToJimple_jj_Topics$nonrefs;
typedef struct _jc_soot_javaToJimple_jj_Topics$object	_jc_soot_javaToJimple_jj_Topics$object;

typedef struct _jc_soot_javaToJimple_jj_Topics$fields_struct	_jc_soot_javaToJimple_jj_Topics$fields_struct;
typedef const struct _jc_soot_javaToJimple_jj_Topics$vmethods	_jc_soot_javaToJimple_jj_Topics$vmethods;
typedef const struct _jc_soot_javaToJimple_jj_Topics$vtable	_jc_soot_javaToJimple_jj_Topics$vtable;
typedef const struct _jc_soot_javaToJimple_jj_Topics$vtype	_jc_soot_javaToJimple_jj_Topics$vtype;

// Class fields structure
struct _jc_soot_javaToJimple_jj_Topics$fields_struct {
	struct _jc_java_lang_String$object	*jj;
};
extern _jc_soot_javaToJimple_jj_Topics$fields_struct _jc_soot_javaToJimple_jj_Topics$class_fields;

// Constructors
extern void _jc_soot_javaToJimple_jj_Topics$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_jj_Topics$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_soot_javaToJimple_jj_Topics$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_javaToJimple_jj_Topics$vmethods {
};

// Vtable
struct _jc_soot_javaToJimple_jj_Topics$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_javaToJimple_jj_Topics$vmethods	soot_javaToJimple_jj_Topics;
};

// Vtype
struct _jc_soot_javaToJimple_jj_Topics$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_jj_Topics$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_jj_Topics$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_jj_Topics$refs {
    _jc_soot_javaToJimple_jj_Topics$sub_refs	soot_javaToJimple_jj_Topics;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_jj_Topics$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_jj_Topics$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_javaToJimple_jj_Topics$sub_nonrefs	soot_javaToJimple_jj_Topics;
};

// Object instance structure
struct _jc_soot_javaToJimple_jj_Topics$object {
	_jc_soot_javaToJimple_jj_Topics$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_jj_Topics$vtype	*vtype;
	_jc_soot_javaToJimple_jj_Topics$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_jj_Topics$vtype _jc_soot_javaToJimple_jj_Topics$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_jj_Topics, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_jj_Topics$class_object;

#endif	/* _JC_soot_javaToJimple_jj_Topics_H_ */
